@@ -40,10 +40,11 @@ def piecewise_sample(stationarity_change_points,is_high,index,max_index):
 
 def normalize_adjustment(feature_values):
     mod_vals=np.ceil(feature_values)
-    vals2=(feature_values==2)*1.1
-    vals3=(feature_values==3)*1.25
-    vals4=(feature_values>3)*1.5
-    return(vals2+vals3+vals4)
+    vals=(mod_vals==1)
+    vals2=(mod_vals==2)*1.1
+    vals3=(mod_vals==3)*1.25
+    vals4=(mod_vals>3)*1.5
+    return(vals+vals2+vals3+vals4)
 
 
 
